==> cscec5b-test-api-3.0.1-20231008.073019-17-sources.jar: com/ejianc/business/test/vo/PrizeTenderVO.java <==
package com.ejianc.business.test.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 奖项业绩实体
 * 
 * @author generator
 * 
 */
public class PrizeTenderVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Integer pkPrize; // 奖项主键，递增
    private String ts; // 时间戳
    private String pkTender; // 项目业绩主键
    private String projectName; // 项目名称
    private String prizeName; // 奖项名称
    private String prizeType; // 奖项类别
    private String prizeSmall; // 奖项小类
    private String prizeLevel; // 奖项级别
    private String awardYear; // 获奖年度
    private String awardTime; // 获奖时间
    private String validPeriod; // 有效期
    private String awardCorp; // 颁奖单位
    private String declareCorp; // 申报单位
    private String winCorp; // 获奖名义
    private String originalFile; // 原件所在地
    private String fileType; // 扫描件类型
    private String uploadFile; // 奖项扫描件链接地址
    private String linkurl; // 证书及文件官网链接
    private String modifier; // 
    private String joinTime; // 录入时间
    private String startTime; // 项目开工时间
    private String endTime; // 项目竣工时间
    private String prizeNum; // 工法、专利等文号
    private String prizeCode; // 工法、专利等编号
    private String completeMan; // 完成人
    

    public Integer getPkPrize() {
        return pkPrize;
    }

    public void setPkPrize(Integer pkPrize) {
        this.pkPrize = pkPrize;
    }
    public String getTs() {
        return ts;
    }

    public void setTs(String ts) {
        this.ts = ts;
    }
    public String getPkTender() {
        return pkTender;
    }

    public void setPkTender(String pkTender) {
        this.pkTender = pkTender;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getPrizeName() {
        return prizeName;
    }

    public void setPrizeName(String prizeName) {
        this.prizeName = prizeName;
    }
    public String getPrizeType() {
        return prizeType;
    }

    public void setPrizeType(String prizeType) {
        this.prizeType = prizeType;
    }
    public String getPrizeSmall() {
        return prizeSmall;
    }

    public void setPrizeSmall(String prizeSmall) {
        this.prizeSmall = prizeSmall;
    }
    public String getPrizeLevel() {
        return prizeLevel;
    }

    public void setPrizeLevel(String prizeLevel) {
        this.prizeLevel = prizeLevel;
    }
    public String getAwardYear() {
        return awardYear;
    }

    public void setAwardYear(String awardYear) {
        this.awardYear = awardYear;
    }
    public String getAwardTime() {
        return awardTime;
    }

    public void setAwardTime(String awardTime) {
        this.awardTime = awardTime;
    }
    public String getValidPeriod() {
        return validPeriod;
    }

    public void setValidPeriod(String validPeriod) {
        this.validPeriod = validPeriod;
    }
    public String getAwardCorp() {
        return awardCorp;
    }

    public void setAwardCorp(String awardCorp) {
        this.awardCorp = awardCorp;
    }
    public String getDeclareCorp() {
        return declareCorp;
    }

    public void setDeclareCorp(String declareCorp) {
        this.declareCorp = declareCorp;
    }
    public String getWinCorp() {
        return winCorp;
    }

    public void setWinCorp(String winCorp) {
        this.winCorp = winCorp;
    }
    public String getOriginalFile() {
        return originalFile;
    }

    public void setOriginalFile(String originalFile) {
        this.originalFile = originalFile;
    }
    public String getFileType() {
        return fileType;
    }

    public void setFileType(String fileType) {
        this.fileType = fileType;
    }
    public String getUploadFile() {
        return uploadFile;
    }

    public void setUploadFile(String uploadFile) {
        this.uploadFile = uploadFile;
    }
    public String getLinkurl() {
        return linkurl;
    }

    public void setLinkurl(String linkurl) {
        this.linkurl = linkurl;
    }
    public String getModifier() {
        return modifier;
    }

    public void setModifier(String modifier) {
        this.modifier = modifier;
    }
    public String getJoinTime() {
        return joinTime;
    }

    public void setJoinTime(String joinTime) {
        this.joinTime = joinTime;
    }
    public String getStartTime() {
        return startTime;
    }

    public void setStartTime(String startTime) {
        this.startTime = startTime;
    }
    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }
    public String getPrizeNum() {
        return prizeNum;
    }

    public void setPrizeNum(String prizeNum) {
        this.prizeNum = prizeNum;
    }
    public String getPrizeCode() {
        return prizeCode;
    }

    public void setPrizeCode(String prizeCode) {
        this.prizeCode = prizeCode;
    }
    public String getCompleteMan() {
        return completeMan;
    }

    public void setCompleteMan(String completeMan) {
        this.completeMan = completeMan;
    }
    
}

==> cscec5b-test-api-3.0.1-20231019.134736-20-sources.jar: com/ejianc/business/test/vo/PrizeTenderVO.java <==
package com.ejianc.business.test.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 奖项业绩实体
 * 
 * @author generator
 * 
 */
public class PrizeTenderVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Integer pkPrize; // 奖项主键，递增
    private String ts; // 时间戳

    private String pkTender; // 项目业绩主键
    private String billCode; // 单据编号
    private String prizeName; // 奖项名称
    private String prizeLevel; // 奖项级别

    private String awardTime; // 获奖时间
    private String validPeriod; // 有效期
    private String giveCorp; // 颁奖单位
    private String declareCorp; // 申报单位
    private String winCorp; // 获奖名义

    private String originalFile; // 原件所在地
    private String fileType; // 扫描件类型
    private String uploadLink; // 奖项扫描件链接地址
    private String officalLink; // 证书及文件官网链接
    private String modifier; //

    private String joinTime; // 录入时间
    private String prizeNum; // 工法、专利等文号
    private String prizeCode; // 工法、专利等编号
    private String completeMan; // 完成人

    public Integer getPkPrize() {
        return pkPrize;
    }

    public void setPkPrize(Integer pkPrize) {
        this.pkPrize = pkPrize;
    }

    public String getTs() {
        return ts;
    }

    public void setTs(String ts) {
        this.ts = ts;
    }

    public String getPkTender() {
        return pkTender;
    }

    public void setPkTender(String pkTender) {
        this.pkTender = pkTender;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getPrizeName() {
        return prizeName;
    }

    public void setPrizeName(String prizeName) {
        this.prizeName = prizeName;
    }

    public String getPrizeLevel() {
        return prizeLevel;
    }

    public void setPrizeLevel(String prizeLevel) {
        this.prizeLevel = prizeLevel;
    }

    public String getAwardTime() {
        return awardTime;
    }

    public void setAwardTime(String awardTime) {
        this.awardTime = awardTime;
    }

    public String getValidPeriod() {
        return validPeriod;
    }

    public void setValidPeriod(String validPeriod) {
        this.validPeriod = validPeriod;
    }

    public String getGiveCorp() {
        return giveCorp;
    }

    public void setGiveCorp(String giveCorp) {
        this.giveCorp = giveCorp;
    }

    public String getDeclareCorp() {
        return declareCorp;
    }

    public void setDeclareCorp(String declareCorp) {
        this.declareCorp = declareCorp;
    }

    public String getWinCorp() {
        return winCorp;
    }

    public void setWinCorp(String winCorp) {
        this.winCorp = winCorp;
    }

    public String getOriginalFile() {
        return originalFile;
    }

    public void setOriginalFile(String originalFile) {
        this.originalFile = originalFile;
    }

    public String getFileType() {
        return fileType;
    }

    public void setFileType(String fileType) {
        this.fileType = fileType;
    }

    public String getUploadLink() {
        return uploadLink;
    }

    public void setUploadLink(String uploadLink) {
        this.uploadLink = uploadLink;
    }

    public String getOfficalLink() {
        return officalLink;
    }

    public void setOfficalLink(String officalLink) {
        this.officalLink = officalLink;
    }

    public String getModifier() {
        return modifier;
    }

    public void setModifier(String modifier) {
        this.modifier = modifier;
    }

    public String getJoinTime() {
        return joinTime;
    }

    public void setJoinTime(String joinTime) {
        this.joinTime = joinTime;
    }

    public String getPrizeNum() {
        return prizeNum;
    }

    public void setPrizeNum(String prizeNum) {
        this.prizeNum = prizeNum;
    }

    public String getPrizeCode() {
        return prizeCode;
    }

    public void setPrizeCode(String prizeCode) {
        this.prizeCode = prizeCode;
    }

    public String getCompleteMan() {
        return completeMan;
    }

    public void setCompleteMan(String completeMan) {
        this.completeMan = completeMan;
    }
}
